==> http_client_error_status-8.x-2.1.tar.gz: http_client_error_status/tests/src/Functional/BlockConditionPageTest.php <==
<?php

namespace Drupal\Tests\http_client_error_status\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Core\Url;

/**
 * Tests that the Block Conditions work.
 *
 * @group http_client_error_status
 */
class BlockConditionPageTest extends BrowserTestBase {
  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['block', 'http_client_error_status'];

  protected $defaultTheme = 'classy';

  /**
   * We use the standard profile.
   *
   * @var string
   */
  protected $profile = 'standard';

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    // Create and login with user who can administer blocks.
    $this->drupalLogin($this->drupalCreateUser([
      'administer blocks',
      'access administration pages',
    ]));

    $default_theme = $this->config('system.theme')->get('default');
    $plugin_id = 'system_powered_by_block';

    $settings = [
      'id' => strtolower($this->randomMachineName(8)),
      'region' => 'footer',
      'theme' => $default_theme,
      'label' => 'Powered Test block',
      'label_display' => 'visible',
      'visibility' => [
        'http_client_error_status' => [
          'request_404' => 1
        ]
      ]
    ];

    $this->drupalPlaceBlock($plugin_id, $settings);

  }

  /**
   * Test block is visible on 404 page.
   */
  public function testBlockVisible404Page() {

    $this->drupalGet($this->randomString());
    $assert = $this->assertSession();
    $assert->statusCodeEquals(404);
    $assert->pageTextContains('Powered Test block');
    
  }

  /**
   * Test block is not visible on 200 page.
   */
  public function testBlockNotVisible200Page() {
  
    $this->drupalGet(Url::fromRoute('<front>'));
    $assert = $this->assertSession();
    $assert->statusCodeEquals(200);
    $assert->pageTextNotContains('Powered Test block');
    
  }

}

==> http_client_error_status-8.x-2.4.tar.gz: http_client_error_status/tests/src/Functional/BlockConditionPageTest.php <==
<?php

namespace Drupal\Tests\http_client_error_status\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Core\Url;

/**
 * Tests that the Block Conditions work.
 *
 * @group http_client_error_status
 */
class BlockConditionPageTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['block', 'http_client_error_status'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'classy';

  /**
   * We use the standard profile.
   *
   * @var string
   */
  protected $profile = 'standard';

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    // Create and login with user who can administer blocks.
    $this->drupalLogin($this->drupalCreateUser([
      'administer blocks',
      'access administration pages',
    ]));

    $default_theme = $this->config('system.theme')->get('default');
    $plugin_id = 'system_powered_by_block';

    $settings = [
      'id' => strtolower($this->randomMachineName(8)),
      'region' => 'footer',
      'theme' => $default_theme,
      'label' => 'Powered Test block',
      'label_display' => 'visible',
      'visibility' => [
        'http_client_error_status' => [
          'request_404' => 1,
        ],
      ],
    ];

    $this->drupalPlaceBlock($plugin_id, $settings);

  }

  /**
   * Test block is visible on 404 page.
   */
  public function testBlockVisible404Page() {

    $this->drupalGet('randomstring-rD6ve4bN4a5Z');
    $assert = $this->assertSession();
    $assert->statusCodeEquals(404);
    $assert->pageTextContains('Powered Test block');

  }

  /**
   * Test block is not visible on 200 page.
   */
  public function testBlockNotVisible200Page() {

    $this->drupalGet(Url::fromRoute('<front>'));
    $assert = $this->assertSession();
    $assert->statusCodeEquals(200);
    $assert->pageTextNotContains('Powered Test block');

  }

}
